@@ -1,8 +1,8 @@
 MixNRMI2 <-
 function (x, probs = c(0.025, 0.5, 0.975), Alpha = 1, Beta = 0, 
     Gama = 0.4, distr.k = 1, distr.py0 = 1, distr.pz0 = 2, mu.pz0 = 3, 
-    sigma.pz0 = sqrt(10), delta = 4, kappa = 2, Delta = 2, Nm = 50, 
-    Nx = 100, Nit = 1000, Pbi = 0.1, epsilon = NULL, printtime = TRUE) 
+    sigma.pz0 = sqrt(10), delta = 4, kappa = 2, Delta = 2, Meps = 0.01, 
+    Nx = 100, Nit = 500, Pbi = 0.1, epsilon = NULL, printtime = TRUE) 
 {
     if (is.null(distr.k)) 
         stop("Argument distr.k is NULL. Should be provided. See help for details.")
@@ -26,6 +26,7 @@ function (x, probs = c(0.025, 0.5, 0.975), Alpha = 1, Beta = 0,
     fx <- matrix(NA, nrow = n, ncol = Nit)
     R <- seq(Nit)
     U <- seq(Nit)
+    Nmt <- seq(Nit)
     mu.py0 = mean(x)
     sigma.py0 = sd(x)
     for (j in seq(Nit)) {
@@ -40,9 +41,9 @@ function (x, probs = c(0.025, 0.5, 0.975), Alpha = 1, Beta = 0,
         if (Gama != 0) 
             u <- gs3(u, n = n, r = rstar, alpha = Alpha, beta = Beta, 
                 gama = Gama, delta = Delta)
-        w <- cumsum(rgamma(Nm, 1, 1))
-        JiC <- MvInv(w, u = u, alpha = Alpha, beta = Beta, gama = Gama, 
-            N = 3001)
+        JiC <- MvInv(eps = Meps, u = u, alpha = Alpha, beta = Beta, 
+            gama = Gama, N = 50001)
+        Nm <- length(JiC)
         TauyC <- rk(Nm, distr = distr.py0, mu = mu.py0, sigma = sigma.py0)
         TauzC <- rk(Nm, distr = distr.pz0, mu = mu.pz0, sigma = sigma.pz0)
         tt <- gsYZstar(ystar, zstar, nstar, rstar, idx, x, delta, 
@@ -66,6 +67,7 @@ function (x, probs = c(0.025, 0.5, 0.975), Alpha = 1, Beta = 0,
         fx[, j] <- fcondXA2(x, distr = distr.k, Tauy, Tauz, J)
         R[j] <- rstar
         U[j] <- u
+        Nmt[j] <- Nm
     }
     biseq <- seq(floor(Pbi * Nit))
     Fxx <- Fxx[, -biseq]
@@ -79,6 +81,6 @@ function (x, probs = c(0.025, 0.5, 0.975), Alpha = 1, Beta = 0,
         cat(" >>> Total processing time (sec.):\n")
         print(procTime <- proc.time() - tInit)
     }
-    return(list(xx = xx, qx = qx, cpo = cpo, R = R, U = U, Nx = Nx, 
-        Nit = Nit, Pbi = Pbi, procTime = procTime))
+    return(list(xx = xx, qx = qx, cpo = cpo, R = R, U = U, Nm = Nmt, 
+        Nx = Nx, Nit = Nit, Pbi = Pbi, procTime = procTime))
 }
