@@ -1,8 +1,6 @@
 MvInv <-
-function (w, u, alpha, beta, gama, N) 
+function (eps, u, alpha, beta, gama, N) 
 {
-    n <- length(w)
-    v <- rep(NA, n)
     x <- -log(seq(from = exp(-1e-05), to = exp(-10), length = N))
     f <- alpha/gamma(1 - gama) * x^(-(1 + gama)) * exp(-(u + 
         beta) * x)
@@ -10,6 +8,13 @@ function (w, u, alpha, beta, gama, N)
     h <- (f[-1] + f[-N])/2
     Mv <- rep(0, N)
     for (i in seq(N - 1, 1)) Mv[i] <- Mv[i + 1] + dx[i] * h[i]
-    for (j in seq(n)) v[j] <- x[which.min(Mv > w[j])]
+    err <- 1
+    w <- 0
+    v <- NULL
+    while (err > eps) {
+        w <- w + rgamma(1, 1, 1)
+        v <- c(v, x[which.min(Mv > w)])
+        err <- min(v)/sum(v)
+    }
     return(v)
 }
